Class: PureCloud::CallConversationNotificationCallMediaParticipant

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloud/models/call_conversation_notification_call_media_participant.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CallConversationNotificationCallMediaParticipant

Returns a new instance of CallConversationNotificationCallMediaParticipant.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 195

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

  
  if attributes[:'id']
    self.id = attributes[:'id']
  end
  
  if attributes[:'name']
    self.name = attributes[:'name']
  end
  
  if attributes[:'address']
    self.address = attributes[:'address']
  end
  
  if attributes[:'startTime']
    self.start_time = attributes[:'startTime']
  end
  
  if attributes[:'connectedTime']
    self.connected_time = attributes[:'connectedTime']
  end
  
  if attributes[:'endTime']
    self.end_time = attributes[:'endTime']
  end
  
  if attributes[:'startHoldTime']
    self.start_hold_time = attributes[:'startHoldTime']
  end
  
  if attributes[:'purpose']
    self.purpose = attributes[:'purpose']
  end
  
  if attributes[:'state']
    self.state = attributes[:'state']
  end
  
  if attributes[:'direction']
    self.direction = attributes[:'direction']
  end
  
  if attributes[:'disconnectType']
    self.disconnect_type = attributes[:'disconnectType']
  end
  
  if attributes[:'held']
    self.held = attributes[:'held']
  end
  
  if attributes[:'wrapupRequired']
    self.wrapup_required = attributes[:'wrapupRequired']
  end
  
  if attributes[:'wrapupPrompt']
    self.wrapup_prompt = attributes[:'wrapupPrompt']
  end
  
  if attributes[:'user']
    self.user = attributes[:'user']
  end
  
  if attributes[:'queue']
    self.queue = attributes[:'queue']
  end
  
  if attributes[:'attributes']
    if (value = attributes[:'attributes']).is_a?(Array)
      self.attributes = value
    end
  end
  
  if attributes[:'errorInfo']
    self.error_info = attributes[:'errorInfo']
  end
  
  if attributes[:'script']
    self.script = attributes[:'script']
  end
  
  if attributes[:'wrapupTimeoutMs']
    self.wrapup_timeout_ms = attributes[:'wrapupTimeoutMs']
  end
  
  if attributes[:'wrapupSkipped']
    self.wrapup_skipped = attributes[:'wrapupSkipped']
  end
  
  if attributes[:'muted']
    self.muted = attributes[:'muted']
  end
  
  if attributes[:'confined']
    self.confined = attributes[:'confined']
  end
  
  if attributes[:'recording']
    self.recording = attributes[:'recording']
  end
  
  if attributes[:'recordingState']
    self.recording_state = attributes[:'recordingState']
  end
  
  if attributes[:'group']
    self.group = attributes[:'group']
  end
  
  if attributes[:'ani']
    self.ani = attributes[:'ani']
  end
  
  if attributes[:'dnis']
    self.dnis = attributes[:'dnis']
  end
  
  if attributes[:'documentId']
    self.document_id = attributes[:'documentId']
  end
  
  if attributes[:'monitoredParticipantId']
    self.monitored_participant_id = attributes[:'monitoredParticipantId']
  end
  
  if attributes[:'consultParticipantId']
    self.consult_participant_id = attributes[:'consultParticipantId']
  end
  
  if attributes[:'faxStatus']
    self.fax_status = attributes[:'faxStatus']
  end
  
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



25
26
27
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 25

def address
  @address
end

#aniObject

Returns the value of attribute ani.



73
74
75
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 73

def ani
  @ani
end

#attributesObject

Returns the value of attribute attributes.



53
54
55
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 53

def attributes
  @attributes
end

#confinedObject

Returns the value of attribute confined.



65
66
67
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 65

def confined
  @confined
end

#connected_timeObject

Returns the value of attribute connected_time.



29
30
31
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 29

def connected_time
  @connected_time
end

#consult_participant_idObject

Returns the value of attribute consult_participant_id.



81
82
83
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 81

def consult_participant_id
  @consult_participant_id
end

#directionObject

Returns the value of attribute direction.



39
40
41
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 39

def direction
  @direction
end

#disconnect_typeObject

Returns the value of attribute disconnect_type.



41
42
43
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 41

def disconnect_type
  @disconnect_type
end

#dnisObject

Returns the value of attribute dnis.



75
76
77
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 75

def dnis
  @dnis
end

#document_idObject

Returns the value of attribute document_id.



77
78
79
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 77

def document_id
  @document_id
end

#end_timeObject

Returns the value of attribute end_time.



31
32
33
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 31

def end_time
  @end_time
end

#error_infoObject

Returns the value of attribute error_info.



55
56
57
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 55

def error_info
  @error_info
end

#fax_statusObject

Returns the value of attribute fax_status.



83
84
85
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 83

def fax_status
  @fax_status
end

#groupObject

Returns the value of attribute group.



71
72
73
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 71

def group
  @group
end

#heldObject

Returns the value of attribute held.



43
44
45
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 43

def held
  @held
end

#idObject

Returns the value of attribute id.



21
22
23
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 21

def id
  @id
end

#monitored_participant_idObject

Returns the value of attribute monitored_participant_id.



79
80
81
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 79

def monitored_participant_id
  @monitored_participant_id
end

#mutedObject

Returns the value of attribute muted.



63
64
65
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 63

def muted
  @muted
end

#nameObject

Returns the value of attribute name.



23
24
25
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 23

def name
  @name
end

#purposeObject

Returns the value of attribute purpose.



35
36
37
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 35

def purpose
  @purpose
end

#queueObject

Returns the value of attribute queue.



51
52
53
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 51

def queue
  @queue
end

#recordingObject

Returns the value of attribute recording.



67
68
69
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 67

def recording
  @recording
end

#recording_stateObject

Returns the value of attribute recording_state.



69
70
71
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 69

def recording_state
  @recording_state
end

#scriptObject

Returns the value of attribute script.



57
58
59
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 57

def script
  @script
end

#start_hold_timeObject

Returns the value of attribute start_hold_time.



33
34
35
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 33

def start_hold_time
  @start_hold_time
end

#start_timeObject

Returns the value of attribute start_time.



27
28
29
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 27

def start_time
  @start_time
end

#stateObject

Returns the value of attribute state.



37
38
39
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 37

def state
  @state
end

#userObject

Returns the value of attribute user.



49
50
51
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 49

def user
  @user
end

#wrapup_promptObject

Returns the value of attribute wrapup_prompt.



47
48
49
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 47

def wrapup_prompt
  @wrapup_prompt
end

#wrapup_requiredObject

Returns the value of attribute wrapup_required.



45
46
47
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 45

def wrapup_required
  @wrapup_required
end

#wrapup_skippedObject

Returns the value of attribute wrapup_skipped.



61
62
63
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 61

def wrapup_skipped
  @wrapup_skipped
end

#wrapup_timeout_msObject

Returns the value of attribute wrapup_timeout_ms.



59
60
61
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 59

def wrapup_timeout_ms
  @wrapup_timeout_ms
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 86

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'name' => :'name',
    
    :'address' => :'address',
    
    :'start_time' => :'startTime',
    
    :'connected_time' => :'connectedTime',
    
    :'end_time' => :'endTime',
    
    :'start_hold_time' => :'startHoldTime',
    
    :'purpose' => :'purpose',
    
    :'state' => :'state',
    
    :'direction' => :'direction',
    
    :'disconnect_type' => :'disconnectType',
    
    :'held' => :'held',
    
    :'wrapup_required' => :'wrapupRequired',
    
    :'wrapup_prompt' => :'wrapupPrompt',
    
    :'user' => :'user',
    
    :'queue' => :'queue',
    
    :'attributes' => :'attributes',
    
    :'error_info' => :'errorInfo',
    
    :'script' => :'script',
    
    :'wrapup_timeout_ms' => :'wrapupTimeoutMs',
    
    :'wrapup_skipped' => :'wrapupSkipped',
    
    :'muted' => :'muted',
    
    :'confined' => :'confined',
    
    :'recording' => :'recording',
    
    :'recording_state' => :'recordingState',
    
    :'group' => :'group',
    
    :'ani' => :'ani',
    
    :'dnis' => :'dnis',
    
    :'document_id' => :'documentId',
    
    :'monitored_participant_id' => :'monitoredParticipantId',
    
    :'consult_participant_id' => :'consultParticipantId',
    
    :'fax_status' => :'faxStatus'
    
  }
end

.swagger_typesObject

Attribute type mapping.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 157

def self.swagger_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'address' => :'String',
    :'start_time' => :'DateTime',
    :'connected_time' => :'DateTime',
    :'end_time' => :'DateTime',
    :'start_hold_time' => :'DateTime',
    :'purpose' => :'String',
    :'state' => :'String',
    :'direction' => :'String',
    :'disconnect_type' => :'String',
    :'held' => :'BOOLEAN',
    :'wrapup_required' => :'BOOLEAN',
    :'wrapup_prompt' => :'String',
    :'user' => :'CallbackConversationNotificationUser',
    :'queue' => :'CallConversationNotificationUriReference',
    :'attributes' => :'Hash<String, String>',
    :'error_info' => :'CallConversationNotificationErrorInfo',
    :'script' => :'CallConversationNotificationUriReference',
    :'wrapup_timeout_ms' => :'Integer',
    :'wrapup_skipped' => :'BOOLEAN',
    :'muted' => :'BOOLEAN',
    :'confined' => :'BOOLEAN',
    :'recording' => :'BOOLEAN',
    :'recording_state' => :'String',
    :'group' => :'CallConversationNotificationUriReference',
    :'ani' => :'String',
    :'dnis' => :'String',
    :'document_id' => :'String',
    :'monitored_participant_id' => :'String',
    :'consult_participant_id' => :'String',
    :'fax_status' => :'CallConversationNotificationFaxStatus'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Check equality by comparing each attribute.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 371

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      address == o.address &&
      start_time == o.start_time &&
      connected_time == o.connected_time &&
      end_time == o.end_time &&
      start_hold_time == o.start_hold_time &&
      purpose == o.purpose &&
      state == o.state &&
      direction == o.direction &&
      disconnect_type == o.disconnect_type &&
      held == o.held &&
      wrapup_required == o.wrapup_required &&
      wrapup_prompt == o.wrapup_prompt &&
      user == o.user &&
      queue == o.queue &&
      attributes == o.attributes &&
      error_info == o.error_info &&
      script == o.script &&
      wrapup_timeout_ms == o.wrapup_timeout_ms &&
      wrapup_skipped == o.wrapup_skipped &&
      muted == o.muted &&
      confined == o.confined &&
      recording == o.recording &&
      recording_state == o.recording_state &&
      group == o.group &&
      ani == o.ani &&
      dnis == o.dnis &&
      document_id == o.document_id &&
      monitored_participant_id == o.monitored_participant_id &&
      consult_participant_id == o.consult_participant_id &&
      fax_status == o.fax_status
end

#_deserialize(type, value) ⇒ Object



438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 438

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 498

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 419

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Returns:

  • (Boolean)

See Also:

  • `==` method


409
410
411
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 409

def eql?(o)
  self == o
end

#hashObject

Calculate hash code according to all attributes.



414
415
416
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 414

def hash
  [id, name, address, start_time, connected_time, end_time, start_hold_time, purpose, state, direction, disconnect_type, held, wrapup_required, wrapup_prompt, user, queue, attributes, error_info, script, wrapup_timeout_ms, wrapup_skipped, muted, confined, recording, recording_state, group, ani, dnis, document_id, monitored_participant_id, consult_participant_id, fax_status].hash
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



481
482
483
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 481

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



486
487
488
489
490
491
492
493
494
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 486

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



476
477
478
# File 'lib/purecloud/models/call_conversation_notification_call_media_participant.rb', line 476

def to_s
  to_hash.to_s
end