Class: PureCloud::ConversationNotificationCall
- Inherits:
-
Object
- Object
- PureCloud::ConversationNotificationCall
- Defined in:
- lib/purecloud/models/conversation_notification_call.rb
Instance Attribute Summary collapse
-
#_self ⇒ Object
Returns the value of attribute _self.
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#confined ⇒ Object
Returns the value of attribute confined.
-
#connected_time ⇒ Object
Returns the value of attribute connected_time.
-
#direction ⇒ Object
Returns the value of attribute direction.
-
#disconnect_reasons ⇒ Object
Returns the value of attribute disconnect_reasons.
-
#disconnect_type ⇒ Object
Returns the value of attribute disconnect_type.
-
#disconnected_time ⇒ Object
Returns the value of attribute disconnected_time.
-
#document_id ⇒ Object
Returns the value of attribute document_id.
-
#error_info ⇒ Object
Returns the value of attribute error_info.
-
#fax_status ⇒ Object
Returns the value of attribute fax_status.
-
#held ⇒ Object
Returns the value of attribute held.
-
#id ⇒ Object
Returns the value of attribute id.
-
#muted ⇒ Object
Returns the value of attribute muted.
-
#other ⇒ Object
Returns the value of attribute other.
-
#recording ⇒ Object
Returns the value of attribute recording.
-
#recording_state ⇒ Object
Returns the value of attribute recording_state.
-
#start_hold_time ⇒ Object
Returns the value of attribute start_hold_time.
-
#state ⇒ Object
Returns the value of attribute state.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Check equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Object
Calculate hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConversationNotificationCall
constructor
A new instance of ConversationNotificationCall.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
Constructor Details
#initialize(attributes = {}) ⇒ ConversationNotificationCall
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo} if attributes[:'id'] self.id = attributes[:'id'] end if attributes[:'state'] self.state = attributes[:'state'] end if attributes[:'recording'] self.recording = attributes[:'recording'] end if attributes[:'recordingState'] self.recording_state = attributes[:'recordingState'] end if attributes[:'muted'] self.muted = attributes[:'muted'] end if attributes[:'confined'] self.confined = attributes[:'confined'] end if attributes[:'held'] self.held = attributes[:'held'] end if attributes[:'errorInfo'] self.error_info = attributes[:'errorInfo'] end if attributes[:'disconnectType'] self.disconnect_type = attributes[:'disconnectType'] end if attributes[:'startHoldTime'] self.start_hold_time = attributes[:'startHoldTime'] end if attributes[:'direction'] self.direction = attributes[:'direction'] end if attributes[:'documentId'] self.document_id = attributes[:'documentId'] end if attributes[:'self'] self._self = attributes[:'self'] end if attributes[:'other'] self.other = attributes[:'other'] end if attributes[:'connectedTime'] self.connected_time = attributes[:'connectedTime'] end if attributes[:'disconnectedTime'] self.disconnected_time = attributes[:'disconnectedTime'] end if attributes[:'disconnectReasons'] if (value = attributes[:'disconnectReasons']).is_a?(Array) self.disconnect_reasons = value end end if attributes[:'faxStatus'] self.fax_status = attributes[:'faxStatus'] end if attributes[:'additionalProperties'] self.additional_properties = attributes[:'additionalProperties'] end end |
Instance Attribute Details
#_self ⇒ Object
Returns the value of attribute _self.
45 46 47 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 45 def _self @_self end |
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
57 58 59 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 57 def additional_properties @additional_properties end |
#confined ⇒ Object
Returns the value of attribute confined.
31 32 33 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 31 def confined @confined end |
#connected_time ⇒ Object
Returns the value of attribute connected_time.
49 50 51 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 49 def connected_time @connected_time end |
#direction ⇒ Object
Returns the value of attribute direction.
41 42 43 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 41 def direction @direction end |
#disconnect_reasons ⇒ Object
Returns the value of attribute disconnect_reasons.
53 54 55 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 53 def disconnect_reasons @disconnect_reasons end |
#disconnect_type ⇒ Object
Returns the value of attribute disconnect_type.
37 38 39 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 37 def disconnect_type @disconnect_type end |
#disconnected_time ⇒ Object
Returns the value of attribute disconnected_time.
51 52 53 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 51 def disconnected_time @disconnected_time end |
#document_id ⇒ Object
Returns the value of attribute document_id.
43 44 45 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 43 def document_id @document_id end |
#error_info ⇒ Object
Returns the value of attribute error_info.
35 36 37 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 35 def error_info @error_info end |
#fax_status ⇒ Object
Returns the value of attribute fax_status.
55 56 57 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 55 def fax_status @fax_status end |
#held ⇒ Object
Returns the value of attribute held.
33 34 35 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 33 def held @held end |
#id ⇒ Object
Returns the value of attribute id.
21 22 23 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 21 def id @id end |
#muted ⇒ Object
Returns the value of attribute muted.
29 30 31 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 29 def muted @muted end |
#other ⇒ Object
Returns the value of attribute other.
47 48 49 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 47 def other @other end |
#recording ⇒ Object
Returns the value of attribute recording.
25 26 27 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 25 def recording @recording end |
#recording_state ⇒ Object
Returns the value of attribute recording_state.
27 28 29 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 27 def recording_state @recording_state end |
#start_hold_time ⇒ Object
Returns the value of attribute start_hold_time.
39 40 41 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 39 def start_hold_time @start_hold_time end |
#state ⇒ Object
Returns the value of attribute state.
23 24 25 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 23 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 60 def self.attribute_map { :'id' => :'id', :'state' => :'state', :'recording' => :'recording', :'recording_state' => :'recordingState', :'muted' => :'muted', :'confined' => :'confined', :'held' => :'held', :'error_info' => :'errorInfo', :'disconnect_type' => :'disconnectType', :'start_hold_time' => :'startHoldTime', :'direction' => :'direction', :'document_id' => :'documentId', :'_self' => :'self', :'other' => :'other', :'connected_time' => :'connectedTime', :'disconnected_time' => :'disconnectedTime', :'disconnect_reasons' => :'disconnectReasons', :'fax_status' => :'faxStatus', :'additional_properties' => :'additionalProperties' } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 105 def self.swagger_types { :'id' => :'String', :'state' => :'String', :'recording' => :'BOOLEAN', :'recording_state' => :'String', :'muted' => :'BOOLEAN', :'confined' => :'BOOLEAN', :'held' => :'BOOLEAN', :'error_info' => :'ConversationNotificationErrorInfo', :'disconnect_type' => :'String', :'start_hold_time' => :'DateTime', :'direction' => :'String', :'document_id' => :'String', :'_self' => :'ConversationNotificationSelf', :'other' => :'ConversationNotificationAddress', :'connected_time' => :'DateTime', :'disconnected_time' => :'DateTime', :'disconnect_reasons' => :'Array<ConversationNotificationDisconnectReasons>', :'fax_status' => :'ConversationNotificationFaxStatus', :'additional_properties' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Check equality by comparing each attribute.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 254 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && state == o.state && recording == o.recording && recording_state == o.recording_state && muted == o.muted && confined == o.confined && held == o.held && error_info == o.error_info && disconnect_type == o.disconnect_type && start_hold_time == o.start_hold_time && direction == o.direction && document_id == o.document_id && _self == o._self && other == o.other && connected_time == o.connected_time && disconnected_time == o.disconnected_time && disconnect_reasons == o.disconnect_reasons && fax_status == o.fax_status && additional_properties == o.additional_properties end |
#_deserialize(type, value) ⇒ Object
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 308 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 368 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 289 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Object
Calculate hash code according to all attributes.
284 285 286 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 284 def hash [id, state, recording, recording_state, muted, confined, held, error_info, disconnect_type, start_hold_time, direction, document_id, _self, other, connected_time, disconnected_time, disconnect_reasons, fax_status, additional_properties].hash end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
351 352 353 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 351 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
356 357 358 359 360 361 362 363 364 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
346 347 348 |
# File 'lib/purecloud/models/conversation_notification_call.rb', line 346 def to_s to_hash.to_s end |