Class: PureCloud::ConversationNotificationChat

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloud/models/conversation_notification_chat.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConversationNotificationChat

Returns a new instance of ConversationNotificationChat.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 80

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

  
  if attributes[:'state']
    self.state = attributes[:'state']
  end
  
  if attributes[:'id']
    self.id = attributes[:'id']
  end
  
  if attributes[:'roomId']
    self.room_id = attributes[:'roomId']
  end
  
  if attributes[:'held']
    self.held = attributes[:'held']
  end
  
  if attributes[:'disconnectType']
    self.disconnect_type = attributes[:'disconnectType']
  end
  
  if attributes[:'startHoldTime']
    self.start_hold_time = attributes[:'startHoldTime']
  end
  
  if attributes[:'connectedTime']
    self.connected_time = attributes[:'connectedTime']
  end
  
  if attributes[:'disconnectedTime']
    self.disconnected_time = attributes[:'disconnectedTime']
  end
  
  if attributes[:'additionalProperties']
    self.additional_properties = attributes[:'additionalProperties']
  end
  
end

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



37
38
39
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 37

def additional_properties
  @additional_properties
end

#connected_timeObject

Returns the value of attribute connected_time.



33
34
35
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 33

def connected_time
  @connected_time
end

#disconnect_typeObject

Returns the value of attribute disconnect_type.



29
30
31
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 29

def disconnect_type
  @disconnect_type
end

#disconnected_timeObject

Returns the value of attribute disconnected_time.



35
36
37
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 35

def disconnected_time
  @disconnected_time
end

#heldObject

Returns the value of attribute held.



27
28
29
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 27

def held
  @held
end

#idObject

Returns the value of attribute id.



23
24
25
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 23

def id
  @id
end

#room_idObject

Returns the value of attribute room_id.



25
26
27
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 25

def room_id
  @room_id
end

#start_hold_timeObject

Returns the value of attribute start_hold_time.



31
32
33
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 31

def start_hold_time
  @start_hold_time
end

#stateObject

Returns the value of attribute state.



21
22
23
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 21

def state
  @state
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 40

def self.attribute_map
  {
    
    :'state' => :'state',
    
    :'id' => :'id',
    
    :'room_id' => :'roomId',
    
    :'held' => :'held',
    
    :'disconnect_type' => :'disconnectType',
    
    :'start_hold_time' => :'startHoldTime',
    
    :'connected_time' => :'connectedTime',
    
    :'disconnected_time' => :'disconnectedTime',
    
    :'additional_properties' => :'additionalProperties'
    
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 65

def self.swagger_types
  {
    :'state' => :'String',
    :'id' => :'String',
    :'room_id' => :'String',
    :'held' => :'BOOLEAN',
    :'disconnect_type' => :'String',
    :'start_hold_time' => :'DateTime',
    :'connected_time' => :'DateTime',
    :'disconnected_time' => :'DateTime',
    :'additional_properties' => :'Object'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Check equality by comparing each attribute.



144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      state == o.state &&
      id == o.id &&
      room_id == o.room_id &&
      held == o.held &&
      disconnect_type == o.disconnect_type &&
      start_hold_time == o.start_hold_time &&
      connected_time == o.connected_time &&
      disconnected_time == o.disconnected_time &&
      additional_properties == o.additional_properties
end

#_deserialize(type, value) ⇒ Object



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 188

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 248

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 169

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 159

def eql?(o)
  self == o
end

#hashObject

Calculate hash code according to all attributes.



164
165
166
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 164

def hash
  [state, id, room_id, held, disconnect_type, start_hold_time, connected_time, disconnected_time, additional_properties].hash
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



231
232
233
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 231

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



236
237
238
239
240
241
242
243
244
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



226
227
228
# File 'lib/purecloud/models/conversation_notification_chat.rb', line 226

def to_s
  to_hash.to_s
end