Class: PureCloud::ConversationNotificationEmail

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloud/models/conversation_notification_email.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConversationNotificationEmail

Returns a new instance of ConversationNotificationEmail.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/purecloud/models/conversation_notification_email.rb', line 90

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

  
  if attributes[:'id']
    self.id = attributes[:'id']
  end
  
  if attributes[:'state']
    self.state = attributes[:'state']
  end
  
  if attributes[:'held']
    self.held = attributes[:'held']
  end
  
  if attributes[:'subject']
    self.subject = attributes[:'subject']
  end
  
  if attributes[:'messagesSent']
    self.messages_sent = attributes[:'messagesSent']
  end
  
  if attributes[:'errorInfo']
    self.error_info = attributes[:'errorInfo']
  end
  
  if attributes[:'disconnectType']
    self.disconnect_type = attributes[:'disconnectType']
  end
  
  if attributes[:'startHoldTime']
    self.start_hold_time = attributes[:'startHoldTime']
  end
  
  if attributes[:'connectedTime']
    self.connected_time = attributes[:'connectedTime']
  end
  
  if attributes[:'disconnectedTime']
    self.disconnected_time = attributes[:'disconnectedTime']
  end
  
  if attributes[:'additionalProperties']
    self.additional_properties = attributes[:'additionalProperties']
  end
  
end

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



41
42
43
# File 'lib/purecloud/models/conversation_notification_email.rb', line 41

def additional_properties
  @additional_properties
end

#connected_timeObject

Returns the value of attribute connected_time.



37
38
39
# File 'lib/purecloud/models/conversation_notification_email.rb', line 37

def connected_time
  @connected_time
end

#disconnect_typeObject

Returns the value of attribute disconnect_type.



33
34
35
# File 'lib/purecloud/models/conversation_notification_email.rb', line 33

def disconnect_type
  @disconnect_type
end

#disconnected_timeObject

Returns the value of attribute disconnected_time.



39
40
41
# File 'lib/purecloud/models/conversation_notification_email.rb', line 39

def disconnected_time
  @disconnected_time
end

#error_infoObject

Returns the value of attribute error_info.



31
32
33
# File 'lib/purecloud/models/conversation_notification_email.rb', line 31

def error_info
  @error_info
end

#heldObject

Returns the value of attribute held.



25
26
27
# File 'lib/purecloud/models/conversation_notification_email.rb', line 25

def held
  @held
end

#idObject

Returns the value of attribute id.



21
22
23
# File 'lib/purecloud/models/conversation_notification_email.rb', line 21

def id
  @id
end

#messages_sentObject

Returns the value of attribute messages_sent.



29
30
31
# File 'lib/purecloud/models/conversation_notification_email.rb', line 29

def messages_sent
  @messages_sent
end

#start_hold_timeObject

Returns the value of attribute start_hold_time.



35
36
37
# File 'lib/purecloud/models/conversation_notification_email.rb', line 35

def start_hold_time
  @start_hold_time
end

#stateObject

Returns the value of attribute state.



23
24
25
# File 'lib/purecloud/models/conversation_notification_email.rb', line 23

def state
  @state
end

#subjectObject

Returns the value of attribute subject.



27
28
29
# File 'lib/purecloud/models/conversation_notification_email.rb', line 27

def subject
  @subject
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/purecloud/models/conversation_notification_email.rb', line 44

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'state' => :'state',
    
    :'held' => :'held',
    
    :'subject' => :'subject',
    
    :'messages_sent' => :'messagesSent',
    
    :'error_info' => :'errorInfo',
    
    :'disconnect_type' => :'disconnectType',
    
    :'start_hold_time' => :'startHoldTime',
    
    :'connected_time' => :'connectedTime',
    
    :'disconnected_time' => :'disconnectedTime',
    
    :'additional_properties' => :'additionalProperties'
    
  }
end

.swagger_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/purecloud/models/conversation_notification_email.rb', line 73

def self.swagger_types
  {
    :'id' => :'String',
    :'state' => :'String',
    :'held' => :'BOOLEAN',
    :'subject' => :'String',
    :'messages_sent' => :'Integer',
    :'error_info' => :'ConversationNotificationErrorDetails',
    :'disconnect_type' => :'String',
    :'start_hold_time' => :'DateTime',
    :'connected_time' => :'DateTime',
    :'disconnected_time' => :'DateTime',
    :'additional_properties' => :'Object'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Check equality by comparing each attribute.



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/purecloud/models/conversation_notification_email.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      state == o.state &&
      held == o.held &&
      subject == o.subject &&
      messages_sent == o.messages_sent &&
      error_info == o.error_info &&
      disconnect_type == o.disconnect_type &&
      start_hold_time == o.start_hold_time &&
      connected_time == o.connected_time &&
      disconnected_time == o.disconnected_time &&
      additional_properties == o.additional_properties
end

#_deserialize(type, value) ⇒ Object



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/purecloud/models/conversation_notification_email.rb', line 208

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/purecloud/models/conversation_notification_email.rb', line 268

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/purecloud/models/conversation_notification_email.rb', line 189

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/purecloud/models/conversation_notification_email.rb', line 179

def eql?(o)
  self == o
end

#hashObject

Calculate hash code according to all attributes.



184
185
186
# File 'lib/purecloud/models/conversation_notification_email.rb', line 184

def hash
  [id, state, held, subject, messages_sent, error_info, disconnect_type, start_hold_time, connected_time, disconnected_time, additional_properties].hash
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



251
252
253
# File 'lib/purecloud/models/conversation_notification_email.rb', line 251

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



256
257
258
259
260
261
262
263
264
# File 'lib/purecloud/models/conversation_notification_email.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



246
247
248
# File 'lib/purecloud/models/conversation_notification_email.rb', line 246

def to_s
  to_hash.to_s
end