Class: PureCloud::CreateCallbackCommand

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloud/models/create_callback_command.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateCallbackCommand

Returns a new instance of CreateCallbackCommand.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/purecloud/models/create_callback_command.rb', line 86

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

  
  if attributes[:'scriptId']
    self.script_id = attributes[:'scriptId']
  end
  
  if attributes[:'queueId']
    self.queue_id = attributes[:'queueId']
  end
  
  if attributes[:'routingData']
    self.routing_data = attributes[:'routingData']
  end
  
  if attributes[:'callbackUserName']
    self.callback_user_name = attributes[:'callbackUserName']
  end
  
  if attributes[:'callbackNumbers']
    if (value = attributes[:'callbackNumbers']).is_a?(Array)
      self.callback_numbers = value
    end
  end
  
  if attributes[:'callbackScheduledTime']
    self.callback_scheduled_time = attributes[:'callbackScheduledTime']
  end
  
  if attributes[:'countryCode']
    self.country_code = attributes[:'countryCode']
  end
  
  if attributes[:'isAutomated']
    self.is_automated = attributes[:'isAutomated']
  else
    self.is_automated = false
  end
  
  if attributes[:'automatedCallbackConfigId']
    self.automated_callback_config_id = attributes[:'automatedCallbackConfigId']
  end
  
  if attributes[:'additionalInfo']
    self.additional_info = attributes[:'additionalInfo']
  end
  
end

Instance Attribute Details

#additional_infoObject

Returns the value of attribute additional_info.



40
41
42
# File 'lib/purecloud/models/create_callback_command.rb', line 40

def additional_info
  @additional_info
end

#automated_callback_config_idObject

Returns the value of attribute automated_callback_config_id.



38
39
40
# File 'lib/purecloud/models/create_callback_command.rb', line 38

def automated_callback_config_id
  @automated_callback_config_id
end

#callback_numbersObject

Returns the value of attribute callback_numbers.



29
30
31
# File 'lib/purecloud/models/create_callback_command.rb', line 29

def callback_numbers
  @callback_numbers
end

#callback_scheduled_timeObject

Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



32
33
34
# File 'lib/purecloud/models/create_callback_command.rb', line 32

def callback_scheduled_time
  @callback_scheduled_time
end

#callback_user_nameObject

Returns the value of attribute callback_user_name.



27
28
29
# File 'lib/purecloud/models/create_callback_command.rb', line 27

def callback_user_name
  @callback_user_name
end

#country_codeObject

Returns the value of attribute country_code.



34
35
36
# File 'lib/purecloud/models/create_callback_command.rb', line 34

def country_code
  @country_code
end

#is_automatedObject

Returns the value of attribute is_automated.



36
37
38
# File 'lib/purecloud/models/create_callback_command.rb', line 36

def is_automated
  @is_automated
end

#queue_idObject

Returns the value of attribute queue_id.



23
24
25
# File 'lib/purecloud/models/create_callback_command.rb', line 23

def queue_id
  @queue_id
end

#routing_dataObject

Returns the value of attribute routing_data.



25
26
27
# File 'lib/purecloud/models/create_callback_command.rb', line 25

def routing_data
  @routing_data
end

#script_idObject

Returns the value of attribute script_id.



21
22
23
# File 'lib/purecloud/models/create_callback_command.rb', line 21

def script_id
  @script_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/purecloud/models/create_callback_command.rb', line 43

def self.attribute_map
  {
    
    :'script_id' => :'scriptId',
    
    :'queue_id' => :'queueId',
    
    :'routing_data' => :'routingData',
    
    :'callback_user_name' => :'callbackUserName',
    
    :'callback_numbers' => :'callbackNumbers',
    
    :'callback_scheduled_time' => :'callbackScheduledTime',
    
    :'country_code' => :'countryCode',
    
    :'is_automated' => :'isAutomated',
    
    :'automated_callback_config_id' => :'automatedCallbackConfigId',
    
    :'additional_info' => :'additionalInfo'
    
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/purecloud/models/create_callback_command.rb', line 70

def self.swagger_types
  {
    :'script_id' => :'String',
    :'queue_id' => :'String',
    :'routing_data' => :'RoutingData',
    :'callback_user_name' => :'String',
    :'callback_numbers' => :'Array<String>',
    :'callback_scheduled_time' => :'DateTime',
    :'country_code' => :'String',
    :'is_automated' => :'BOOLEAN',
    :'automated_callback_config_id' => :'String',
    :'additional_info' => :'AdditionalInfo'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Check equality by comparing each attribute.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/purecloud/models/create_callback_command.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      script_id == o.script_id &&
      queue_id == o.queue_id &&
      routing_data == o.routing_data &&
      callback_user_name == o.callback_user_name &&
      callback_numbers == o.callback_numbers &&
      callback_scheduled_time == o.callback_scheduled_time &&
      country_code == o.country_code &&
      is_automated == o.is_automated &&
      automated_callback_config_id == o.automated_callback_config_id &&
      additional_info == o.additional_info
end

#_deserialize(type, value) ⇒ Object



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/purecloud/models/create_callback_command.rb', line 185

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/purecloud/models/create_callback_command.rb', line 245

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/purecloud/models/create_callback_command.rb', line 166

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/purecloud/models/create_callback_command.rb', line 156

def eql?(o)
  self == o
end

#hashObject

Calculate hash code according to all attributes.



161
162
163
# File 'lib/purecloud/models/create_callback_command.rb', line 161

def hash
  [script_id, queue_id, routing_data, callback_user_name, callback_numbers, callback_scheduled_time, country_code, is_automated, automated_callback_config_id, additional_info].hash
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



228
229
230
# File 'lib/purecloud/models/create_callback_command.rb', line 228

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



233
234
235
236
237
238
239
240
241
# File 'lib/purecloud/models/create_callback_command.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



223
224
225
# File 'lib/purecloud/models/create_callback_command.rb', line 223

def to_s
  to_hash.to_s
end