Class: PureCloud::EmailConversationNotificationParticipants

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloud/models/email_conversation_notification_participants.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailConversationNotificationParticipants

Returns a new instance of EmailConversationNotificationParticipants.



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 150

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

  
  if attributes[:'queue']
    self.queue = attributes[:'queue']
  end
  
  if attributes[:'held']
    self.held = attributes[:'held']
  end
  
  if attributes[:'errorInfo']
    self.error_info = attributes[:'errorInfo']
  end
  
  if attributes[:'connectedTime']
    self.connected_time = attributes[:'connectedTime']
  end
  
  if attributes[:'subject']
    self.subject = attributes[:'subject']
  end
  
  if attributes[:'wrapupSkipped']
    self.wrapup_skipped = attributes[:'wrapupSkipped']
  end
  
  if attributes[:'direction']
    self.direction = attributes[:'direction']
  end
  
  if attributes[:'wrapupRequired']
    self.wrapup_required = attributes[:'wrapupRequired']
  end
  
  if attributes[:'state']
    self.state = attributes[:'state']
  end
  
  if attributes[:'messagesSent']
    self.messages_sent = attributes[:'messagesSent']
  end
  
  if attributes[:'purpose']
    self.purpose = attributes[:'purpose']
  end
  
  if attributes[:'script']
    self.script = attributes[:'script']
  end
  
  if attributes[:'endTime']
    self.end_time = attributes[:'endTime']
  end
  
  if attributes[:'id']
    self.id = attributes[:'id']
  end
  
  if attributes[:'startTime']
    self.start_time = attributes[:'startTime']
  end
  
  if attributes[:'disconnectType']
    self.disconnect_type = attributes[:'disconnectType']
  end
  
  if attributes[:'wrapupPrompt']
    self.wrapup_prompt = attributes[:'wrapupPrompt']
  end
  
  if attributes[:'address']
    self.address = attributes[:'address']
  end
  
  if attributes[:'name']
    self.name = attributes[:'name']
  end
  
  if attributes[:'startHoldTime']
    self.start_hold_time = attributes[:'startHoldTime']
  end
  
  if attributes[:'wrapupTimeoutMs']
    self.wrapup_timeout_ms = attributes[:'wrapupTimeoutMs']
  end
  
  if attributes[:'attributes']
    if (value = attributes[:'attributes']).is_a?(Array)
      self.attributes = value
    end
  end
  
  if attributes[:'user']
    self.user = attributes[:'user']
  end
  
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



55
56
57
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 55

def address
  @address
end

#attributesObject

Returns the value of attribute attributes.



63
64
65
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 63

def attributes
  @attributes
end

#connected_timeObject

Returns the value of attribute connected_time.



27
28
29
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 27

def connected_time
  @connected_time
end

#directionObject

Returns the value of attribute direction.



33
34
35
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 33

def direction
  @direction
end

#disconnect_typeObject

Returns the value of attribute disconnect_type.



51
52
53
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 51

def disconnect_type
  @disconnect_type
end

#end_timeObject

Returns the value of attribute end_time.



45
46
47
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 45

def end_time
  @end_time
end

#error_infoObject

Returns the value of attribute error_info.



25
26
27
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 25

def error_info
  @error_info
end

#heldObject

Returns the value of attribute held.



23
24
25
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 23

def held
  @held
end

#idObject

Returns the value of attribute id.



47
48
49
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 47

def id
  @id
end

#messages_sentObject

Returns the value of attribute messages_sent.



39
40
41
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 39

def messages_sent
  @messages_sent
end

#nameObject

Returns the value of attribute name.



57
58
59
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 57

def name
  @name
end

#purposeObject

Returns the value of attribute purpose.



41
42
43
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 41

def purpose
  @purpose
end

#queueObject

Returns the value of attribute queue.



21
22
23
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 21

def queue
  @queue
end

#scriptObject

Returns the value of attribute script.



43
44
45
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 43

def script
  @script
end

#start_hold_timeObject

Returns the value of attribute start_hold_time.



59
60
61
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 59

def start_hold_time
  @start_hold_time
end

#start_timeObject

Returns the value of attribute start_time.



49
50
51
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 49

def start_time
  @start_time
end

#stateObject

Returns the value of attribute state.



37
38
39
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 37

def state
  @state
end

#subjectObject

Returns the value of attribute subject.



29
30
31
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 29

def subject
  @subject
end

#userObject

Returns the value of attribute user.



65
66
67
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 65

def user
  @user
end

#wrapup_promptObject

Returns the value of attribute wrapup_prompt.



53
54
55
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 53

def wrapup_prompt
  @wrapup_prompt
end

#wrapup_requiredObject

Returns the value of attribute wrapup_required.



35
36
37
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 35

def wrapup_required
  @wrapup_required
end

#wrapup_skippedObject

Returns the value of attribute wrapup_skipped.



31
32
33
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 31

def wrapup_skipped
  @wrapup_skipped
end

#wrapup_timeout_msObject

Returns the value of attribute wrapup_timeout_ms.



61
62
63
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 61

def wrapup_timeout_ms
  @wrapup_timeout_ms
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 68

def self.attribute_map
  {
    
    :'queue' => :'queue',
    
    :'held' => :'held',
    
    :'error_info' => :'errorInfo',
    
    :'connected_time' => :'connectedTime',
    
    :'subject' => :'subject',
    
    :'wrapup_skipped' => :'wrapupSkipped',
    
    :'direction' => :'direction',
    
    :'wrapup_required' => :'wrapupRequired',
    
    :'state' => :'state',
    
    :'messages_sent' => :'messagesSent',
    
    :'purpose' => :'purpose',
    
    :'script' => :'script',
    
    :'end_time' => :'endTime',
    
    :'id' => :'id',
    
    :'start_time' => :'startTime',
    
    :'disconnect_type' => :'disconnectType',
    
    :'wrapup_prompt' => :'wrapupPrompt',
    
    :'address' => :'address',
    
    :'name' => :'name',
    
    :'start_hold_time' => :'startHoldTime',
    
    :'wrapup_timeout_ms' => :'wrapupTimeoutMs',
    
    :'attributes' => :'attributes',
    
    :'user' => :'user'
    
  }
end

.swagger_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 121

def self.swagger_types
  {
    :'queue' => :'EmailConversationNotificationUriReference',
    :'held' => :'BOOLEAN',
    :'error_info' => :'EmailConversationNotificationErrorInfo',
    :'connected_time' => :'DateTime',
    :'subject' => :'String',
    :'wrapup_skipped' => :'BOOLEAN',
    :'direction' => :'String',
    :'wrapup_required' => :'BOOLEAN',
    :'state' => :'String',
    :'messages_sent' => :'Integer',
    :'purpose' => :'String',
    :'script' => :'EmailConversationNotificationUriReference',
    :'end_time' => :'DateTime',
    :'id' => :'String',
    :'start_time' => :'DateTime',
    :'disconnect_type' => :'String',
    :'wrapup_prompt' => :'String',
    :'address' => :'String',
    :'name' => :'String',
    :'start_hold_time' => :'DateTime',
    :'wrapup_timeout_ms' => :'Integer',
    :'attributes' => :'Hash<String, String>',
    :'user' => :'CallbackConversationNotificationUser'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Check equality by comparing each attribute.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 281

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      queue == o.queue &&
      held == o.held &&
      error_info == o.error_info &&
      connected_time == o.connected_time &&
      subject == o.subject &&
      wrapup_skipped == o.wrapup_skipped &&
      direction == o.direction &&
      wrapup_required == o.wrapup_required &&
      state == o.state &&
      messages_sent == o.messages_sent &&
      purpose == o.purpose &&
      script == o.script &&
      end_time == o.end_time &&
      id == o.id &&
      start_time == o.start_time &&
      disconnect_type == o.disconnect_type &&
      wrapup_prompt == o.wrapup_prompt &&
      address == o.address &&
      name == o.name &&
      start_hold_time == o.start_hold_time &&
      wrapup_timeout_ms == o.wrapup_timeout_ms &&
      attributes == o.attributes &&
      user == o.user
end

#_deserialize(type, value) ⇒ Object



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 339

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 399

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 320

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 310

def eql?(o)
  self == o
end

#hashObject

Calculate hash code according to all attributes.



315
316
317
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 315

def hash
  [queue, held, error_info, connected_time, subject, wrapup_skipped, direction, wrapup_required, state, messages_sent, purpose, script, end_time, id, start_time, disconnect_type, wrapup_prompt, address, name, start_hold_time, wrapup_timeout_ms, attributes, user].hash
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



382
383
384
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 382

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



387
388
389
390
391
392
393
394
395
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 387

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



377
378
379
# File 'lib/purecloud/models/email_conversation_notification_participants.rb', line 377

def to_s
  to_hash.to_s
end