Class: PureCloud::ForecastMetadata
- Inherits:
-
Object
- Object
- PureCloud::ForecastMetadata
- Defined in:
- lib/purecloud/models/forecast_metadata.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The description of the forecast to be created.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#last_modified_by ⇒ Object
The person who last modified this object.
-
#last_modified_date ⇒ Object
The last modified date time of this object.
-
#metrics ⇒ Object
The metrics the forecast is for.
-
#name ⇒ Object
Returns the value of attribute name.
-
#number_of_periods ⇒ Object
The number of periods to be forecasted for.
-
#period_frequency ⇒ Object
The frequency of the period.
-
#self_uri ⇒ Object
The URI for this object.
-
#status ⇒ Object
The status of the creation of the forecast.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Check equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Object
Calculate hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ForecastMetadata
constructor
A new instance of ForecastMetadata.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
Constructor Details
#initialize(attributes = {}) ⇒ ForecastMetadata
Returns a new instance of ForecastMetadata.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo} if attributes[:'id'] self.id = attributes[:'id'] end if attributes[:'name'] self.name = attributes[:'name'] end if attributes[:'numberOfPeriods'] self.number_of_periods = attributes[:'numberOfPeriods'] end if attributes[:'periodFrequency'] self.period_frequency = attributes[:'periodFrequency'] end if attributes[:'description'] self.description = attributes[:'description'] end if attributes[:'metrics'] if (value = attributes[:'metrics']).is_a?(Array) self.metrics = value end end if attributes[:'lastModifiedDate'] self.last_modified_date = attributes[:'lastModifiedDate'] end if attributes[:'lastModifiedBy'] self.last_modified_by = attributes[:'lastModifiedBy'] end if attributes[:'status'] self.status = attributes[:'status'] end if attributes[:'selfUri'] self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#description ⇒ Object
The description of the forecast to be created
33 34 35 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 33 def description @description end |
#id ⇒ Object
The globally unique identifier for the object.
22 23 24 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 22 def id @id end |
#last_modified_by ⇒ Object
The person who last modified this object
42 43 44 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 42 def last_modified_by @last_modified_by end |
#last_modified_date ⇒ Object
The last modified date time of this object. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
39 40 41 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 39 def last_modified_date @last_modified_date end |
#metrics ⇒ Object
The metrics the forecast is for
36 37 38 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 36 def metrics @metrics end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 24 def name @name end |
#number_of_periods ⇒ Object
The number of periods to be forecasted for
27 28 29 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 27 def number_of_periods @number_of_periods end |
#period_frequency ⇒ Object
The frequency of the period
30 31 32 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 30 def period_frequency @period_frequency end |
#self_uri ⇒ Object
The URI for this object
48 49 50 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 48 def self_uri @self_uri end |
#status ⇒ Object
The status of the creation of the forecast
45 46 47 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 45 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 51 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'number_of_periods' => :'numberOfPeriods', :'period_frequency' => :'periodFrequency', :'description' => :'description', :'metrics' => :'metrics', :'last_modified_date' => :'lastModifiedDate', :'last_modified_by' => :'lastModifiedBy', :'status' => :'status', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 78 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'number_of_periods' => :'Integer', :'period_frequency' => :'String', :'description' => :'String', :'metrics' => :'Array<String>', :'last_modified_date' => :'DateTime', :'last_modified_by' => :'User', :'status' => :'String', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Check equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && number_of_periods == o.number_of_periods && period_frequency == o.period_frequency && description == o.description && metrics == o.metrics && last_modified_date == o.last_modified_date && last_modified_by == o.last_modified_by && status == o.status && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 209 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 269 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Object
Calculate hash code according to all attributes.
185 186 187 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 185 def hash [id, name, number_of_periods, period_frequency, description, metrics, last_modified_date, last_modified_by, status, self_uri].hash end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
252 253 254 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 252 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
257 258 259 260 261 262 263 264 265 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
247 248 249 |
# File 'lib/purecloud/models/forecast_metadata.rb', line 247 def to_s to_hash.to_s end |