Class: PureCloud::ForecastModification
- Inherits:
-
Object
- Object
- PureCloud::ForecastModification
- Defined in:
- lib/purecloud/models/forecast_modification.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
The filters for the modification.
-
#enabled ⇒ Object
Determined if the modification is currently applied.
-
#end_date ⇒ Object
The end of the modified time period.
-
#forecast_id ⇒ Object
The id of the associated forecast.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#last_modified_by ⇒ Object
The last user to change the modification.
-
#last_modified_date ⇒ Object
The last time the modification was changed.
-
#metric ⇒ Object
The metric the modification is appied to.
-
#modification_type ⇒ Object
The type of modification.
-
#modification_value ⇒ Object
The value of the modification.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notes ⇒ Object
Any notes associated with the modification.
-
#priority ⇒ Object
The priority in which the modification is applied.
-
#self_uri ⇒ Object
The URI for this object.
-
#start_date ⇒ Object
The start of the modified time period.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Check equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Object
Calculate hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ForecastModification
constructor
A new instance of ForecastModification.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
Constructor Details
#initialize(attributes = {}) ⇒ ForecastModification
Returns a new instance of ForecastModification.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/purecloud/models/forecast_modification.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo} if attributes[:'id'] self.id = attributes[:'id'] end if attributes[:'name'] self.name = attributes[:'name'] end if attributes[:'forecastId'] self.forecast_id = attributes[:'forecastId'] end if attributes[:'priority'] self.priority = attributes[:'priority'] end if attributes[:'metric'] self.metric = attributes[:'metric'] end if attributes[:'modificationType'] self.modification_type = attributes[:'modificationType'] end if attributes[:'modificationValue'] self.modification_value = attributes[:'modificationValue'] end if attributes[:'startDate'] self.start_date = attributes[:'startDate'] end if attributes[:'endDate'] self.end_date = attributes[:'endDate'] end if attributes[:'attributes'] self.attributes = attributes[:'attributes'] end if attributes[:'enabled'] self.enabled = attributes[:'enabled'] else self.enabled = false end if attributes[:'lastModifiedDate'] self.last_modified_date = attributes[:'lastModifiedDate'] end if attributes[:'lastModifiedBy'] self.last_modified_by = attributes[:'lastModifiedBy'] end if attributes[:'notes'] self.notes = attributes[:'notes'] end if attributes[:'selfUri'] self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#attributes ⇒ Object
The filters for the modification
48 49 50 |
# File 'lib/purecloud/models/forecast_modification.rb', line 48 def attributes @attributes end |
#enabled ⇒ Object
Determined if the modification is currently applied
51 52 53 |
# File 'lib/purecloud/models/forecast_modification.rb', line 51 def enabled @enabled end |
#end_date ⇒ Object
The end of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
45 46 47 |
# File 'lib/purecloud/models/forecast_modification.rb', line 45 def end_date @end_date end |
#forecast_id ⇒ Object
The id of the associated forecast
27 28 29 |
# File 'lib/purecloud/models/forecast_modification.rb', line 27 def forecast_id @forecast_id end |
#id ⇒ Object
The globally unique identifier for the object.
22 23 24 |
# File 'lib/purecloud/models/forecast_modification.rb', line 22 def id @id end |
#last_modified_by ⇒ Object
The last user to change the modification
57 58 59 |
# File 'lib/purecloud/models/forecast_modification.rb', line 57 def last_modified_by @last_modified_by end |
#last_modified_date ⇒ Object
The last time the modification was changed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
54 55 56 |
# File 'lib/purecloud/models/forecast_modification.rb', line 54 def last_modified_date @last_modified_date end |
#metric ⇒ Object
The metric the modification is appied to
33 34 35 |
# File 'lib/purecloud/models/forecast_modification.rb', line 33 def metric @metric end |
#modification_type ⇒ Object
The type of modification
36 37 38 |
# File 'lib/purecloud/models/forecast_modification.rb', line 36 def modification_type @modification_type end |
#modification_value ⇒ Object
The value of the modification
39 40 41 |
# File 'lib/purecloud/models/forecast_modification.rb', line 39 def modification_value @modification_value end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/purecloud/models/forecast_modification.rb', line 24 def name @name end |
#notes ⇒ Object
Any notes associated with the modification
60 61 62 |
# File 'lib/purecloud/models/forecast_modification.rb', line 60 def notes @notes end |
#priority ⇒ Object
The priority in which the modification is applied
30 31 32 |
# File 'lib/purecloud/models/forecast_modification.rb', line 30 def priority @priority end |
#self_uri ⇒ Object
The URI for this object
63 64 65 |
# File 'lib/purecloud/models/forecast_modification.rb', line 63 def self_uri @self_uri end |
#start_date ⇒ Object
The start of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
42 43 44 |
# File 'lib/purecloud/models/forecast_modification.rb', line 42 def start_date @start_date end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/purecloud/models/forecast_modification.rb', line 66 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'forecast_id' => :'forecastId', :'priority' => :'priority', :'metric' => :'metric', :'modification_type' => :'modificationType', :'modification_value' => :'modificationValue', :'start_date' => :'startDate', :'end_date' => :'endDate', :'attributes' => :'attributes', :'enabled' => :'enabled', :'last_modified_date' => :'lastModifiedDate', :'last_modified_by' => :'lastModifiedBy', :'notes' => :'notes', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/purecloud/models/forecast_modification.rb', line 103 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'forecast_id' => :'String', :'priority' => :'Integer', :'metric' => :'String', :'modification_type' => :'String', :'modification_value' => :'Float', :'start_date' => :'DateTime', :'end_date' => :'DateTime', :'attributes' => :'ForecastFilterAttributes', :'enabled' => :'BOOLEAN', :'last_modified_date' => :'DateTime', :'last_modified_by' => :'User', :'notes' => :'String', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Check equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/purecloud/models/forecast_modification.rb', line 214 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && forecast_id == o.forecast_id && priority == o.priority && metric == o.metric && modification_type == o.modification_type && modification_value == o.modification_value && start_date == o.start_date && end_date == o.end_date && attributes == o.attributes && enabled == o.enabled && last_modified_date == o.last_modified_date && last_modified_by == o.last_modified_by && notes == o.notes && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/purecloud/models/forecast_modification.rb', line 264 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/purecloud/models/forecast_modification.rb', line 324 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/purecloud/models/forecast_modification.rb', line 245 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
235 236 237 |
# File 'lib/purecloud/models/forecast_modification.rb', line 235 def eql?(o) self == o end |
#hash ⇒ Object
Calculate hash code according to all attributes.
240 241 242 |
# File 'lib/purecloud/models/forecast_modification.rb', line 240 def hash [id, name, forecast_id, priority, metric, modification_type, modification_value, start_date, end_date, attributes, enabled, last_modified_date, last_modified_by, notes, self_uri].hash end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
307 308 309 |
# File 'lib/purecloud/models/forecast_modification.rb', line 307 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
312 313 314 315 316 317 318 319 320 |
# File 'lib/purecloud/models/forecast_modification.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
302 303 304 |
# File 'lib/purecloud/models/forecast_modification.rb', line 302 def to_s to_hash.to_s end |