Class: PureCloud::ForecastModificationCreation

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloud/models/forecast_modification_creation.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ForecastModificationCreation

Returns a new instance of ForecastModificationCreation.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 112

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

  
  if attributes[:'id']
    self.id = attributes[:'id']
  end
  
  if attributes[:'name']
    self.name = attributes[:'name']
  end
  
  if attributes[:'forecastId']
    self.forecast_id = attributes[:'forecastId']
  end
  
  if attributes[:'priority']
    self.priority = attributes[:'priority']
  end
  
  if attributes[:'metric']
    self.metric = attributes[:'metric']
  end
  
  if attributes[:'modificationType']
    self.modification_type = attributes[:'modificationType']
  end
  
  if attributes[:'modificationValue']
    self.modification_value = attributes[:'modificationValue']
  end
  
  if attributes[:'startDate']
    self.start_date = attributes[:'startDate']
  end
  
  if attributes[:'endDate']
    self.end_date = attributes[:'endDate']
  end
  
  if attributes[:'attributes']
    self.attributes = attributes[:'attributes']
  end
  
  if attributes[:'enabled']
    self.enabled = attributes[:'enabled']
  else
    self.enabled = false
  end
  
  if attributes[:'notes']
    self.notes = attributes[:'notes']
  end
  
  if attributes[:'selfUri']
    self.self_uri = attributes[:'selfUri']
  end
  
end

Instance Attribute Details

#attributesObject

The filters for the modification



48
49
50
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 48

def attributes
  @attributes
end

#enabledObject

Determined if the modification is currently applied



51
52
53
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 51

def enabled
  @enabled
end

#end_dateObject

The end of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



45
46
47
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 45

def end_date
  @end_date
end

#forecast_idObject

The id of the associated forecast



27
28
29
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 27

def forecast_id
  @forecast_id
end

#idObject

The globally unique identifier for the object.



22
23
24
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 22

def id
  @id
end

#metricObject

The metric the modification is appied to



33
34
35
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 33

def metric
  @metric
end

#modification_typeObject

The type of modification



36
37
38
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 36

def modification_type
  @modification_type
end

#modification_valueObject

The value of the modification



39
40
41
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 39

def modification_value
  @modification_value
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 24

def name
  @name
end

#notesObject

Any notes associated with the modification



54
55
56
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 54

def notes
  @notes
end

#priorityObject

The priority in which the modification is applied



30
31
32
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 30

def priority
  @priority
end

#self_uriObject

The URI for this object



57
58
59
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 57

def self_uri
  @self_uri
end

#start_dateObject

The start of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



42
43
44
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 42

def start_date
  @start_date
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 60

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'name' => :'name',
    
    :'forecast_id' => :'forecastId',
    
    :'priority' => :'priority',
    
    :'metric' => :'metric',
    
    :'modification_type' => :'modificationType',
    
    :'modification_value' => :'modificationValue',
    
    :'start_date' => :'startDate',
    
    :'end_date' => :'endDate',
    
    :'attributes' => :'attributes',
    
    :'enabled' => :'enabled',
    
    :'notes' => :'notes',
    
    :'self_uri' => :'selfUri'
    
  }
end

.swagger_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 93

def self.swagger_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'forecast_id' => :'String',
    :'priority' => :'Integer',
    :'metric' => :'String',
    :'modification_type' => :'String',
    :'modification_value' => :'Float',
    :'start_date' => :'DateTime',
    :'end_date' => :'DateTime',
    :'attributes' => :'ForecastFilterAttributes',
    :'enabled' => :'BOOLEAN',
    :'notes' => :'String',
    :'self_uri' => :'String'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Check equality by comparing each attribute.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      forecast_id == o.forecast_id &&
      priority == o.priority &&
      metric == o.metric &&
      modification_type == o.modification_type &&
      modification_value == o.modification_value &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      attributes == o.attributes &&
      enabled == o.enabled &&
      notes == o.notes &&
      self_uri == o.self_uri
end

#_deserialize(type, value) ⇒ Object



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 242

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 302

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 223

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 213

def eql?(o)
  self == o
end

#hashObject

Calculate hash code according to all attributes.



218
219
220
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 218

def hash
  [id, name, forecast_id, priority, metric, modification_type, modification_value, start_date, end_date, attributes, enabled, notes, self_uri].hash
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



285
286
287
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 285

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



290
291
292
293
294
295
296
297
298
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 290

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



280
281
282
# File 'lib/purecloud/models/forecast_modification_creation.rb', line 280

def to_s
  to_hash.to_s
end