Class: PureCloud::NotificationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloud/api/notifications_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ NotificationsApi

Returns a new instance of NotificationsApi.



7
8
9
# File 'lib/purecloud/api/notifications_api.rb', line 7

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



5
6
7
# File 'lib/purecloud/api/notifications_api.rb', line 5

def api_client
  @api_client
end

Instance Method Details

#delete_channels_channel_id_subscriptions(channel_id, opts = {}) ⇒ String

Remove all subscriptions

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


374
375
376
377
# File 'lib/purecloud/api/notifications_api.rb', line 374

def delete_channels_channel_id_subscriptions(channel_id, opts = {})
  data, status_code, headers = delete_channels_channel_id_subscriptions_with_http_info(channel_id, opts)
  return data
end

#delete_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Remove all subscriptions

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/purecloud/api/notifications_api.rb', line 384

def delete_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: NotificationsApi#delete_channels_channel_id_subscriptions ..."
  end
  
  # verify the required parameter 'channel_id' is set
  fail "Missing the required parameter 'channel_id' when calling delete_channels_channel_id_subscriptions" if channel_id.nil?
  
  # resource path
  path = "/api/v2/notifications/channels/{channelId}/subscriptions".sub('{format}','json').sub('{' + 'channelId' + '}', channel_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = ['application/json']
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  

  auth_names = ['PureCloud Auth']
  data, status_code, headers = @api_client.call_api(:DELETE, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#delete_channels_channel_id_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_availabletopics(opts = {}) ⇒ AvailableTopicEntityListing

Get available notification topics.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :expand (Array<String>)

    Which fields, if any, to expand

Returns:



16
17
18
19
# File 'lib/purecloud/api/notifications_api.rb', line 16

def get_availabletopics(opts = {})
  data, status_code, headers = get_availabletopics_with_http_info(opts)
  return data
end

#get_availabletopics_with_http_info(opts = {}) ⇒ Array<(AvailableTopicEntityListing, Fixnum, Hash)>

Get available notification topics.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :expand (Array<String>)

    Which fields, if any, to expand

Returns:



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/purecloud/api/notifications_api.rb', line 26

def get_availabletopics_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: NotificationsApi#get_availabletopics ..."
  end
  
  # resource path
  path = "/api/v2/notifications/availabletopics".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'expand'] = @api_client.build_collection_param(opts[:'expand'], :multi) if opts[:'expand']

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = ['application/json']
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  

  auth_names = ['PureCloud Auth']
  data, status_code, headers = @api_client.call_api(:GET, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'AvailableTopicEntityListing')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#get_availabletopics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_channels(opts = {}) ⇒ ChannelEntityListing

The list of existing channels

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



74
75
76
77
# File 'lib/purecloud/api/notifications_api.rb', line 74

def get_channels(opts = {})
  data, status_code, headers = get_channels_with_http_info(opts)
  return data
end

#get_channels_channel_id_subscriptions(channel_id, opts = {}) ⇒ ChannelTopicEntityListing

The list of all subscriptions for this channel

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



187
188
189
190
# File 'lib/purecloud/api/notifications_api.rb', line 187

def get_channels_channel_id_subscriptions(channel_id, opts = {})
  data, status_code, headers = get_channels_channel_id_subscriptions_with_http_info(channel_id, opts)
  return data
end

#get_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {}) ⇒ Array<(ChannelTopicEntityListing, Fixnum, Hash)>

The list of all subscriptions for this channel

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ChannelTopicEntityListing, Fixnum, Hash)>)

    ChannelTopicEntityListing data, response status code and response headers



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/purecloud/api/notifications_api.rb', line 197

def get_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: NotificationsApi#get_channels_channel_id_subscriptions ..."
  end
  
  # verify the required parameter 'channel_id' is set
  fail "Missing the required parameter 'channel_id' when calling get_channels_channel_id_subscriptions" if channel_id.nil?
  
  # resource path
  path = "/api/v2/notifications/channels/{channelId}/subscriptions".sub('{format}','json').sub('{' + 'channelId' + '}', channel_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = ['application/json']
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  

  auth_names = ['PureCloud Auth']
  data, status_code, headers = @api_client.call_api(:GET, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'ChannelTopicEntityListing')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#get_channels_channel_id_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_channels_with_http_info(opts = {}) ⇒ Array<(ChannelEntityListing, Fixnum, Hash)>

The list of existing channels

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ChannelEntityListing, Fixnum, Hash)>)

    ChannelEntityListing data, response status code and response headers



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/purecloud/api/notifications_api.rb', line 83

def get_channels_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: NotificationsApi#get_channels ..."
  end
  
  # resource path
  path = "/api/v2/notifications/channels".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = ['application/json']
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  

  auth_names = ['PureCloud Auth']
  data, status_code, headers = @api_client.call_api(:GET, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'ChannelEntityListing')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#get_channels\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_channels(opts = {}) ⇒ Channel

Create a new channel There is a limit of 10 channels. Creating an 11th channel will remove the channel with oldest last used date.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



130
131
132
133
# File 'lib/purecloud/api/notifications_api.rb', line 130

def post_channels(opts = {})
  data, status_code, headers = post_channels_with_http_info(opts)
  return data
end

#post_channels_channel_id_subscriptions(channel_id, opts = {}) ⇒ ChannelTopicEntityListing

Add a list of subscriptions to the existing list of subscriptions

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



312
313
314
315
# File 'lib/purecloud/api/notifications_api.rb', line 312

def post_channels_channel_id_subscriptions(channel_id, opts = {})
  data, status_code, headers = post_channels_channel_id_subscriptions_with_http_info(channel_id, opts)
  return data
end

#post_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {}) ⇒ Array<(ChannelTopicEntityListing, Fixnum, Hash)>

Add a list of subscriptions to the existing list of subscriptions

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(ChannelTopicEntityListing, Fixnum, Hash)>)

    ChannelTopicEntityListing data, response status code and response headers



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/purecloud/api/notifications_api.rb', line 323

def post_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: NotificationsApi#post_channels_channel_id_subscriptions ..."
  end
  
  # verify the required parameter 'channel_id' is set
  fail "Missing the required parameter 'channel_id' when calling post_channels_channel_id_subscriptions" if channel_id.nil?
  
  # resource path
  path = "/api/v2/notifications/channels/{channelId}/subscriptions".sub('{format}','json').sub('{' + 'channelId' + '}', channel_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = ['application/json']
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'body'])
  

  auth_names = ['PureCloud Auth']
  data, status_code, headers = @api_client.call_api(:POST, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'ChannelTopicEntityListing')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#post_channels_channel_id_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_channels_with_http_info(opts = {}) ⇒ Array<(Channel, Fixnum, Hash)>

Create a new channel There is a limit of 10 channels. Creating an 11th channel will remove the channel with oldest last used date.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Channel, Fixnum, Hash)>)

    Channel data, response status code and response headers



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/purecloud/api/notifications_api.rb', line 139

def post_channels_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: NotificationsApi#post_channels ..."
  end
  
  # resource path
  path = "/api/v2/notifications/channels".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = ['application/json']
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  

  auth_names = ['PureCloud Auth']
  data, status_code, headers = @api_client.call_api(:POST, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'Channel')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#post_channels\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#put_channels_channel_id_subscriptions(channel_id, opts = {}) ⇒ ChannelTopicEntityListing

Replace the current list of subscriptions with a new list.

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



249
250
251
252
# File 'lib/purecloud/api/notifications_api.rb', line 249

def put_channels_channel_id_subscriptions(channel_id, opts = {})
  data, status_code, headers = put_channels_channel_id_subscriptions_with_http_info(channel_id, opts)
  return data
end

#put_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {}) ⇒ Array<(ChannelTopicEntityListing, Fixnum, Hash)>

Replace the current list of subscriptions with a new list.

Parameters:

  • channel_id

    Channel ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(ChannelTopicEntityListing, Fixnum, Hash)>)

    ChannelTopicEntityListing data, response status code and response headers



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/purecloud/api/notifications_api.rb', line 260

def put_channels_channel_id_subscriptions_with_http_info(channel_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: NotificationsApi#put_channels_channel_id_subscriptions ..."
  end
  
  # verify the required parameter 'channel_id' is set
  fail "Missing the required parameter 'channel_id' when calling put_channels_channel_id_subscriptions" if channel_id.nil?
  
  # resource path
  path = "/api/v2/notifications/channels/{channelId}/subscriptions".sub('{format}','json').sub('{' + 'channelId' + '}', channel_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = ['application/json']
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'body'])
  

  auth_names = ['PureCloud Auth']
  data, status_code, headers = @api_client.call_api(:PUT, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'ChannelTopicEntityListing')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#put_channels_channel_id_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end