Class: PureCloud::Screenshare
- Inherits:
-
Object
- Object
- PureCloud::Screenshare
- Defined in:
- lib/purecloud/models/screenshare.rb
Instance Attribute Summary collapse
-
#connected_time ⇒ Object
The timestamp when this communication was connected in the cloud clock.
-
#context ⇒ Object
The room id context (xmpp jid) for the conference session.
-
#disconnect_type ⇒ Object
System defined string indicating what caused the communication to disconnect.
-
#disconnected_time ⇒ Object
The timestamp when this communication disconnected from the conversation in the provider clock.
-
#id ⇒ Object
A globally unique identifier for this communication.
-
#peer_count ⇒ Object
The number of peer participants from the perspective of the participant in the conference.
-
#provider ⇒ Object
The source provider for the screen share.
-
#sharing ⇒ Object
Indicates whether this participant is sharing their screen.
-
#state ⇒ Object
The connection state of this communication.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Check equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Object
Calculate hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Screenshare
constructor
A new instance of Screenshare.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
Constructor Details
#initialize(attributes = {}) ⇒ Screenshare
Returns a new instance of Screenshare.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/purecloud/models/screenshare.rb', line 89 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo} if attributes[:'state'] self.state = attributes[:'state'] end if attributes[:'id'] self.id = attributes[:'id'] end if attributes[:'context'] self.context = attributes[:'context'] end if attributes[:'sharing'] self.sharing = attributes[:'sharing'] else self.sharing = false end if attributes[:'peerCount'] self.peer_count = attributes[:'peerCount'] end if attributes[:'disconnectType'] self.disconnect_type = attributes[:'disconnectType'] end if attributes[:'connectedTime'] self.connected_time = attributes[:'connectedTime'] end if attributes[:'disconnectedTime'] self.disconnected_time = attributes[:'disconnectedTime'] end if attributes[:'provider'] self.provider = attributes[:'provider'] end end |
Instance Attribute Details
#connected_time ⇒ Object
The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
40 41 42 |
# File 'lib/purecloud/models/screenshare.rb', line 40 def connected_time @connected_time end |
#context ⇒ Object
The room id context (xmpp jid) for the conference session.
28 29 30 |
# File 'lib/purecloud/models/screenshare.rb', line 28 def context @context end |
#disconnect_type ⇒ Object
System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.
37 38 39 |
# File 'lib/purecloud/models/screenshare.rb', line 37 def disconnect_type @disconnect_type end |
#disconnected_time ⇒ Object
The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
43 44 45 |
# File 'lib/purecloud/models/screenshare.rb', line 43 def disconnected_time @disconnected_time end |
#id ⇒ Object
A globally unique identifier for this communication.
25 26 27 |
# File 'lib/purecloud/models/screenshare.rb', line 25 def id @id end |
#peer_count ⇒ Object
The number of peer participants from the perspective of the participant in the conference.
34 35 36 |
# File 'lib/purecloud/models/screenshare.rb', line 34 def peer_count @peer_count end |
#provider ⇒ Object
The source provider for the screen share.
46 47 48 |
# File 'lib/purecloud/models/screenshare.rb', line 46 def provider @provider end |
#sharing ⇒ Object
Indicates whether this participant is sharing their screen.
31 32 33 |
# File 'lib/purecloud/models/screenshare.rb', line 31 def sharing @sharing end |
#state ⇒ Object
The connection state of this communication.
22 23 24 |
# File 'lib/purecloud/models/screenshare.rb', line 22 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/purecloud/models/screenshare.rb', line 49 def self.attribute_map { :'state' => :'state', :'id' => :'id', :'context' => :'context', :'sharing' => :'sharing', :'peer_count' => :'peerCount', :'disconnect_type' => :'disconnectType', :'connected_time' => :'connectedTime', :'disconnected_time' => :'disconnectedTime', :'provider' => :'provider' } end |
.swagger_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/purecloud/models/screenshare.rb', line 74 def self.swagger_types { :'state' => :'String', :'id' => :'String', :'context' => :'String', :'sharing' => :'BOOLEAN', :'peer_count' => :'Integer', :'disconnect_type' => :'String', :'connected_time' => :'DateTime', :'disconnected_time' => :'DateTime', :'provider' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Check equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/purecloud/models/screenshare.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && state == o.state && id == o.id && context == o.context && sharing == o.sharing && peer_count == o.peer_count && disconnect_type == o.disconnect_type && connected_time == o.connected_time && disconnected_time == o.disconnected_time && provider == o.provider end |
#_deserialize(type, value) ⇒ Object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/purecloud/models/screenshare.rb', line 199 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/purecloud/models/screenshare.rb', line 259 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/purecloud/models/screenshare.rb', line 180 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/purecloud/models/screenshare.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Object
Calculate hash code according to all attributes.
175 176 177 |
# File 'lib/purecloud/models/screenshare.rb', line 175 def hash [state, id, context, sharing, peer_count, disconnect_type, connected_time, disconnected_time, provider].hash end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
242 243 244 |
# File 'lib/purecloud/models/screenshare.rb', line 242 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
247 248 249 250 251 252 253 254 255 |
# File 'lib/purecloud/models/screenshare.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
237 238 239 |
# File 'lib/purecloud/models/screenshare.rb', line 237 def to_s to_hash.to_s end |