Class: PureCloud::Recording
- Inherits:
-
Object
- Object
- PureCloud::Recording
- Defined in:
- lib/purecloud/models/recording.rb
Instance Attribute Summary collapse
-
#_path ⇒ Object
Returns the value of attribute _path.
-
#actual_transcode_time_ms ⇒ Object
Returns the value of attribute actual_transcode_time_ms.
-
#annotations ⇒ Object
Returns the value of attribute annotations.
-
#archive_date ⇒ Object
Date time is represented as an ISO-8601 string.
-
#archive_medium ⇒ Object
Returns the value of attribute archive_medium.
-
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
-
#delete_date ⇒ Object
Date time is represented as an ISO-8601 string.
-
#email_transcript ⇒ Object
Returns the value of attribute email_transcript.
-
#end_time ⇒ Object
Returns the value of attribute end_time.
-
#estimated_transcode_time_ms ⇒ Object
Returns the value of attribute estimated_transcode_time_ms.
-
#file_state ⇒ Object
Returns the value of attribute file_state.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#max_allowed_restorations_for_org ⇒ Object
Returns the value of attribute max_allowed_restorations_for_org.
-
#media ⇒ Object
Returns the value of attribute media.
-
#media_uri ⇒ Object
Returns the value of attribute media_uri.
-
#media_uris ⇒ Object
Returns the value of attribute media_uris.
-
#name ⇒ Object
Returns the value of attribute name.
-
#recording_id ⇒ Object
Returns the value of attribute recording_id.
-
#remaining_restorations_allowed_for_org ⇒ Object
Returns the value of attribute remaining_restorations_allowed_for_org.
-
#restore_expiration_time ⇒ Object
Date time is represented as an ISO-8601 string.
-
#self_uri ⇒ Object
The URI for this object.
-
#start_time ⇒ Object
Returns the value of attribute start_time.
-
#transcript ⇒ Object
Returns the value of attribute transcript.
-
#wave_uri ⇒ Object
Returns the value of attribute wave_uri.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Check equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Object
Calculate hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Recording
constructor
A new instance of Recording.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
Constructor Details
#initialize(attributes = {}) ⇒ Recording
Returns a new instance of Recording.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/purecloud/models/recording.rb', line 144 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo} if attributes[:'id'] self.id = attributes[:'id'] end if attributes[:'name'] self.name = attributes[:'name'] end if attributes[:'conversationId'] self.conversation_id = attributes[:'conversationId'] end if attributes[:'path'] self._path = attributes[:'path'] end if attributes[:'startTime'] self.start_time = attributes[:'startTime'] end if attributes[:'endTime'] self.end_time = attributes[:'endTime'] end if attributes[:'media'] self.media = attributes[:'media'] end if attributes[:'mediaUri'] self.media_uri = attributes[:'mediaUri'] end if attributes[:'waveUri'] self.wave_uri = attributes[:'waveUri'] end if attributes[:'annotations'] if (value = attributes[:'annotations']).is_a?(Array) self.annotations = value end end if attributes[:'transcript'] if (value = attributes[:'transcript']).is_a?(Array) self.transcript = value end end if attributes[:'emailTranscript'] if (value = attributes[:'emailTranscript']).is_a?(Array) self.email_transcript = value end end if attributes[:'fileState'] self.file_state = attributes[:'fileState'] end if attributes[:'restoreExpirationTime'] self.restore_expiration_time = attributes[:'restoreExpirationTime'] end if attributes[:'mediaUris'] if (value = attributes[:'mediaUris']).is_a?(Array) self.media_uris = value end end if attributes[:'estimatedTranscodeTimeMs'] self.estimated_transcode_time_ms = attributes[:'estimatedTranscodeTimeMs'] end if attributes[:'actualTranscodeTimeMs'] self.actual_transcode_time_ms = attributes[:'actualTranscodeTimeMs'] end if attributes[:'archiveDate'] self.archive_date = attributes[:'archiveDate'] end if attributes[:'archiveMedium'] self.archive_medium = attributes[:'archiveMedium'] end if attributes[:'deleteDate'] self.delete_date = attributes[:'deleteDate'] end if attributes[:'maxAllowedRestorationsForOrg'] self.max_allowed_restorations_for_org = attributes[:'maxAllowedRestorationsForOrg'] end if attributes[:'remainingRestorationsAllowedForOrg'] self.remaining_restorations_allowed_for_org = attributes[:'remainingRestorationsAllowedForOrg'] end if attributes[:'recordingId'] self.recording_id = attributes[:'recordingId'] end if attributes[:'selfUri'] self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#_path ⇒ Object
Returns the value of attribute _path.
12 13 14 |
# File 'lib/purecloud/models/recording.rb', line 12 def _path @_path end |
#actual_transcode_time_ms ⇒ Object
Returns the value of attribute actual_transcode_time_ms.
39 40 41 |
# File 'lib/purecloud/models/recording.rb', line 39 def actual_transcode_time_ms @actual_transcode_time_ms end |
#annotations ⇒ Object
Returns the value of attribute annotations.
24 25 26 |
# File 'lib/purecloud/models/recording.rb', line 24 def annotations @annotations end |
#archive_date ⇒ Object
Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
42 43 44 |
# File 'lib/purecloud/models/recording.rb', line 42 def archive_date @archive_date end |
#archive_medium ⇒ Object
Returns the value of attribute archive_medium.
44 45 46 |
# File 'lib/purecloud/models/recording.rb', line 44 def archive_medium @archive_medium end |
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
10 11 12 |
# File 'lib/purecloud/models/recording.rb', line 10 def conversation_id @conversation_id end |
#delete_date ⇒ Object
Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
47 48 49 |
# File 'lib/purecloud/models/recording.rb', line 47 def delete_date @delete_date end |
#email_transcript ⇒ Object
Returns the value of attribute email_transcript.
28 29 30 |
# File 'lib/purecloud/models/recording.rb', line 28 def email_transcript @email_transcript end |
#end_time ⇒ Object
Returns the value of attribute end_time.
16 17 18 |
# File 'lib/purecloud/models/recording.rb', line 16 def end_time @end_time end |
#estimated_transcode_time_ms ⇒ Object
Returns the value of attribute estimated_transcode_time_ms.
37 38 39 |
# File 'lib/purecloud/models/recording.rb', line 37 def estimated_transcode_time_ms @estimated_transcode_time_ms end |
#file_state ⇒ Object
Returns the value of attribute file_state.
30 31 32 |
# File 'lib/purecloud/models/recording.rb', line 30 def file_state @file_state end |
#id ⇒ Object
The globally unique identifier for the object.
6 7 8 |
# File 'lib/purecloud/models/recording.rb', line 6 def id @id end |
#max_allowed_restorations_for_org ⇒ Object
Returns the value of attribute max_allowed_restorations_for_org.
49 50 51 |
# File 'lib/purecloud/models/recording.rb', line 49 def max_allowed_restorations_for_org @max_allowed_restorations_for_org end |
#media ⇒ Object
Returns the value of attribute media.
18 19 20 |
# File 'lib/purecloud/models/recording.rb', line 18 def media @media end |
#media_uri ⇒ Object
Returns the value of attribute media_uri.
20 21 22 |
# File 'lib/purecloud/models/recording.rb', line 20 def media_uri @media_uri end |
#media_uris ⇒ Object
Returns the value of attribute media_uris.
35 36 37 |
# File 'lib/purecloud/models/recording.rb', line 35 def media_uris @media_uris end |
#name ⇒ Object
Returns the value of attribute name.
8 9 10 |
# File 'lib/purecloud/models/recording.rb', line 8 def name @name end |
#recording_id ⇒ Object
Returns the value of attribute recording_id.
53 54 55 |
# File 'lib/purecloud/models/recording.rb', line 53 def recording_id @recording_id end |
#remaining_restorations_allowed_for_org ⇒ Object
Returns the value of attribute remaining_restorations_allowed_for_org.
51 52 53 |
# File 'lib/purecloud/models/recording.rb', line 51 def remaining_restorations_allowed_for_org @remaining_restorations_allowed_for_org end |
#restore_expiration_time ⇒ Object
Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
33 34 35 |
# File 'lib/purecloud/models/recording.rb', line 33 def restore_expiration_time @restore_expiration_time end |
#self_uri ⇒ Object
The URI for this object
56 57 58 |
# File 'lib/purecloud/models/recording.rb', line 56 def self_uri @self_uri end |
#start_time ⇒ Object
Returns the value of attribute start_time.
14 15 16 |
# File 'lib/purecloud/models/recording.rb', line 14 def start_time @start_time end |
#transcript ⇒ Object
Returns the value of attribute transcript.
26 27 28 |
# File 'lib/purecloud/models/recording.rb', line 26 def transcript @transcript end |
#wave_uri ⇒ Object
Returns the value of attribute wave_uri.
22 23 24 |
# File 'lib/purecloud/models/recording.rb', line 22 def wave_uri @wave_uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/purecloud/models/recording.rb', line 59 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'conversation_id' => :'conversationId', :'_path' => :'path', :'start_time' => :'startTime', :'end_time' => :'endTime', :'media' => :'media', :'media_uri' => :'mediaUri', :'wave_uri' => :'waveUri', :'annotations' => :'annotations', :'transcript' => :'transcript', :'email_transcript' => :'emailTranscript', :'file_state' => :'fileState', :'restore_expiration_time' => :'restoreExpirationTime', :'media_uris' => :'mediaUris', :'estimated_transcode_time_ms' => :'estimatedTranscodeTimeMs', :'actual_transcode_time_ms' => :'actualTranscodeTimeMs', :'archive_date' => :'archiveDate', :'archive_medium' => :'archiveMedium', :'delete_date' => :'deleteDate', :'max_allowed_restorations_for_org' => :'maxAllowedRestorationsForOrg', :'remaining_restorations_allowed_for_org' => :'remainingRestorationsAllowedForOrg', :'recording_id' => :'recordingId', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/purecloud/models/recording.rb', line 114 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'conversation_id' => :'String', :'_path' => :'String', :'start_time' => :'String', :'end_time' => :'String', :'media' => :'String', :'media_uri' => :'String', :'wave_uri' => :'String', :'annotations' => :'Array<Annotation>', :'transcript' => :'Array<ChatMessage>', :'email_transcript' => :'Array<EmailMessage>', :'file_state' => :'String', :'restore_expiration_time' => :'DateTime', :'media_uris' => :'Hash<String, MediaResult>', :'estimated_transcode_time_ms' => :'Integer', :'actual_transcode_time_ms' => :'Integer', :'archive_date' => :'DateTime', :'archive_medium' => :'String', :'delete_date' => :'DateTime', :'max_allowed_restorations_for_org' => :'Integer', :'remaining_restorations_allowed_for_org' => :'Integer', :'recording_id' => :'String', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Check equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/purecloud/models/recording.rb', line 276 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && conversation_id == o.conversation_id && _path == o._path && start_time == o.start_time && end_time == o.end_time && media == o.media && media_uri == o.media_uri && wave_uri == o.wave_uri && annotations == o.annotations && transcript == o.transcript && email_transcript == o.email_transcript && file_state == o.file_state && restore_expiration_time == o.restore_expiration_time && media_uris == o.media_uris && estimated_transcode_time_ms == o.estimated_transcode_time_ms && actual_transcode_time_ms == o.actual_transcode_time_ms && archive_date == o.archive_date && archive_medium == o.archive_medium && delete_date == o.delete_date && max_allowed_restorations_for_org == o.max_allowed_restorations_for_org && remaining_restorations_allowed_for_org == o.remaining_restorations_allowed_for_org && recording_id == o.recording_id && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/purecloud/models/recording.rb', line 335 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value =~ /^(true|t|yes|y|1)$/i true else false end when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/purecloud/models/recording.rb', line 392 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/purecloud/models/recording.rb', line 316 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
306 307 308 |
# File 'lib/purecloud/models/recording.rb', line 306 def eql?(o) self == o end |
#hash ⇒ Object
Calculate hash code according to all attributes.
311 312 313 |
# File 'lib/purecloud/models/recording.rb', line 311 def hash [id, name, conversation_id, _path, start_time, end_time, media, media_uri, wave_uri, annotations, transcript, email_transcript, file_state, restore_expiration_time, media_uris, estimated_transcode_time_ms, actual_transcode_time_ms, archive_date, archive_medium, delete_date, max_allowed_restorations_for_org, remaining_restorations_allowed_for_org, recording_id, self_uri].hash end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
375 376 377 |
# File 'lib/purecloud/models/recording.rb', line 375 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
380 381 382 383 384 385 386 387 388 |
# File 'lib/purecloud/models/recording.rb', line 380 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
370 371 372 |
# File 'lib/purecloud/models/recording.rb', line 370 def to_s to_hash.to_s end |