Class: PureCloud::UserMe
- Inherits:
-
Object
- Object
- PureCloud::UserMe
- Defined in:
- lib/purecloud/models/user_me.rb
Instance Attribute Summary collapse
-
#addresses ⇒ Object
Email addresses and phone numbers for this user.
-
#adjacents ⇒ Object
The first 50 superiors, direct reports, and siblings of this user.
-
#authorization ⇒ Object
Roles and permissions assigned to the user.
-
#chat ⇒ Object
Returns the value of attribute chat.
-
#conversation_summary ⇒ Object
Summary of conversion statistics for conversation types.
-
#date ⇒ Object
The PureCloud system date time.
-
#department ⇒ Object
Returns the value of attribute department.
-
#direct_reports ⇒ Object
The first 50 direct reports to this user.
-
#email ⇒ Object
Returns the value of attribute email.
-
#favorites ⇒ Object
The first 50 favorited users.
-
#geolocation ⇒ Object
Current geolocation position.
-
#geolocation_settings ⇒ Object
Geolocation settings for user’s organization.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#images ⇒ Object
Returns the value of attribute images.
-
#locations ⇒ Object
The first 100 locations for user’s organization.
-
#name ⇒ Object
Returns the value of attribute name.
-
#org_authorization ⇒ Object
The first 100 organization roles, with applicable permission policies, for user’s organization.
-
#organization ⇒ Object
Organization details for this user.
-
#out_of_office ⇒ Object
Determine if out of office is enabled.
-
#presence ⇒ Object
Active presence.
-
#presence_definitions ⇒ Object
The first 100 presence definitions for user’s organization.
-
#primary_contact_info ⇒ Object
Auto populated from addresses.
-
#profile_skills ⇒ Object
Skills possessed by the user.
-
#routing_status ⇒ Object
ACD routing status.
-
#self_uri ⇒ Object
The URI for this object.
-
#state ⇒ Object
The current state for this user.
-
#station ⇒ Object
Effective, default, and last station information.
-
#superiors ⇒ Object
The first 50 superiors of this user.
-
#title ⇒ Object
Returns the value of attribute title.
-
#username ⇒ Object
Returns the value of attribute username.
-
#version ⇒ Object
Required when updating a user, this value should be the current version of the user.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Check equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Object
Calculate hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserMe
constructor
A new instance of UserMe.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
Constructor Details
#initialize(attributes = {}) ⇒ UserMe
Returns a new instance of UserMe.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/purecloud/models/user_me.rb', line 214 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo} if attributes[:'id'] self.id = attributes[:'id'] end if attributes[:'name'] self.name = attributes[:'name'] end if attributes[:'chat'] self.chat = attributes[:'chat'] end if attributes[:'department'] self.department = attributes[:'department'] end if attributes[:'email'] self.email = attributes[:'email'] end if attributes[:'primaryContactInfo'] if (value = attributes[:'primaryContactInfo']).is_a?(Array) self.primary_contact_info = value end end if attributes[:'addresses'] if (value = attributes[:'addresses']).is_a?(Array) self.addresses = value end end if attributes[:'state'] self.state = attributes[:'state'] end if attributes[:'title'] self.title = attributes[:'title'] end if attributes[:'username'] self.username = attributes[:'username'] end if attributes[:'images'] if (value = attributes[:'images']).is_a?(Array) self.images = value end end if attributes[:'version'] self.version = attributes[:'version'] end if attributes[:'routingStatus'] self.routing_status = attributes[:'routingStatus'] end if attributes[:'presence'] self.presence = attributes[:'presence'] end if attributes[:'conversationSummary'] self.conversation_summary = attributes[:'conversationSummary'] end if attributes[:'outOfOffice'] self.out_of_office = attributes[:'outOfOffice'] end if attributes[:'geolocation'] self.geolocation = attributes[:'geolocation'] end if attributes[:'station'] self.station = attributes[:'station'] end if attributes[:'authorization'] self. = attributes[:'authorization'] end if attributes[:'profileSkills'] if (value = attributes[:'profileSkills']).is_a?(Array) self.profile_skills = value end end if attributes[:'date'] self.date = attributes[:'date'] end if attributes[:'geolocationSettings'] self.geolocation_settings = attributes[:'geolocationSettings'] end if attributes[:'organization'] self.organization = attributes[:'organization'] end if attributes[:'presenceDefinitions'] if (value = attributes[:'presenceDefinitions']).is_a?(Array) self.presence_definitions = value end end if attributes[:'locations'] if (value = attributes[:'locations']).is_a?(Array) self.locations = value end end if attributes[:'orgAuthorization'] if (value = attributes[:'orgAuthorization']).is_a?(Array) self. = value end end if attributes[:'favorites'] if (value = attributes[:'favorites']).is_a?(Array) self.favorites = value end end if attributes[:'superiors'] if (value = attributes[:'superiors']).is_a?(Array) self.superiors = value end end if attributes[:'directReports'] if (value = attributes[:'directReports']).is_a?(Array) self.direct_reports = value end end if attributes[:'adjacents'] self.adjacents = attributes[:'adjacents'] end if attributes[:'selfUri'] self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#addresses ⇒ Object
Email addresses and phone numbers for this user
36 37 38 |
# File 'lib/purecloud/models/user_me.rb', line 36 def addresses @addresses end |
#adjacents ⇒ Object
The first 50 superiors, direct reports, and siblings of this user. Mutually exclusive with superiors and direct reports expands.
102 103 104 |
# File 'lib/purecloud/models/user_me.rb', line 102 def adjacents @adjacents end |
#authorization ⇒ Object
Roles and permissions assigned to the user
69 70 71 |
# File 'lib/purecloud/models/user_me.rb', line 69 def end |
#chat ⇒ Object
Returns the value of attribute chat.
26 27 28 |
# File 'lib/purecloud/models/user_me.rb', line 26 def chat @chat end |
#conversation_summary ⇒ Object
Summary of conversion statistics for conversation types.
57 58 59 |
# File 'lib/purecloud/models/user_me.rb', line 57 def conversation_summary @conversation_summary end |
#date ⇒ Object
The PureCloud system date time.
75 76 77 |
# File 'lib/purecloud/models/user_me.rb', line 75 def date @date end |
#department ⇒ Object
Returns the value of attribute department.
28 29 30 |
# File 'lib/purecloud/models/user_me.rb', line 28 def department @department end |
#direct_reports ⇒ Object
The first 50 direct reports to this user.
99 100 101 |
# File 'lib/purecloud/models/user_me.rb', line 99 def direct_reports @direct_reports end |
#email ⇒ Object
Returns the value of attribute email.
30 31 32 |
# File 'lib/purecloud/models/user_me.rb', line 30 def email @email end |
#favorites ⇒ Object
The first 50 favorited users.
93 94 95 |
# File 'lib/purecloud/models/user_me.rb', line 93 def favorites @favorites end |
#geolocation ⇒ Object
Current geolocation position
63 64 65 |
# File 'lib/purecloud/models/user_me.rb', line 63 def geolocation @geolocation end |
#geolocation_settings ⇒ Object
Geolocation settings for user’s organization.
78 79 80 |
# File 'lib/purecloud/models/user_me.rb', line 78 def geolocation_settings @geolocation_settings end |
#id ⇒ Object
The globally unique identifier for the object.
22 23 24 |
# File 'lib/purecloud/models/user_me.rb', line 22 def id @id end |
#images ⇒ Object
Returns the value of attribute images.
45 46 47 |
# File 'lib/purecloud/models/user_me.rb', line 45 def images @images end |
#locations ⇒ Object
The first 100 locations for user’s organization
87 88 89 |
# File 'lib/purecloud/models/user_me.rb', line 87 def locations @locations end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/purecloud/models/user_me.rb', line 24 def name @name end |
#org_authorization ⇒ Object
The first 100 organization roles, with applicable permission policies, for user’s organization.
90 91 92 |
# File 'lib/purecloud/models/user_me.rb', line 90 def end |
#organization ⇒ Object
Organization details for this user.
81 82 83 |
# File 'lib/purecloud/models/user_me.rb', line 81 def organization @organization end |
#out_of_office ⇒ Object
Determine if out of office is enabled
60 61 62 |
# File 'lib/purecloud/models/user_me.rb', line 60 def out_of_office @out_of_office end |
#presence ⇒ Object
Active presence
54 55 56 |
# File 'lib/purecloud/models/user_me.rb', line 54 def presence @presence end |
#presence_definitions ⇒ Object
The first 100 presence definitions for user’s organization.
84 85 86 |
# File 'lib/purecloud/models/user_me.rb', line 84 def presence_definitions @presence_definitions end |
#primary_contact_info ⇒ Object
Auto populated from addresses.
33 34 35 |
# File 'lib/purecloud/models/user_me.rb', line 33 def primary_contact_info @primary_contact_info end |
#profile_skills ⇒ Object
Skills possessed by the user
72 73 74 |
# File 'lib/purecloud/models/user_me.rb', line 72 def profile_skills @profile_skills end |
#routing_status ⇒ Object
ACD routing status
51 52 53 |
# File 'lib/purecloud/models/user_me.rb', line 51 def routing_status @routing_status end |
#self_uri ⇒ Object
The URI for this object
105 106 107 |
# File 'lib/purecloud/models/user_me.rb', line 105 def self_uri @self_uri end |
#state ⇒ Object
The current state for this user.
39 40 41 |
# File 'lib/purecloud/models/user_me.rb', line 39 def state @state end |
#station ⇒ Object
Effective, default, and last station information
66 67 68 |
# File 'lib/purecloud/models/user_me.rb', line 66 def station @station end |
#superiors ⇒ Object
The first 50 superiors of this user.
96 97 98 |
# File 'lib/purecloud/models/user_me.rb', line 96 def superiors @superiors end |
#title ⇒ Object
Returns the value of attribute title.
41 42 43 |
# File 'lib/purecloud/models/user_me.rb', line 41 def title @title end |
#username ⇒ Object
Returns the value of attribute username.
43 44 45 |
# File 'lib/purecloud/models/user_me.rb', line 43 def username @username end |
#version ⇒ Object
Required when updating a user, this value should be the current version of the user. The current version can be obtained with a GET on the user before doing a PATCH.
48 49 50 |
# File 'lib/purecloud/models/user_me.rb', line 48 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/purecloud/models/user_me.rb', line 108 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'chat' => :'chat', :'department' => :'department', :'email' => :'email', :'primary_contact_info' => :'primaryContactInfo', :'addresses' => :'addresses', :'state' => :'state', :'title' => :'title', :'username' => :'username', :'images' => :'images', :'version' => :'version', :'routing_status' => :'routingStatus', :'presence' => :'presence', :'conversation_summary' => :'conversationSummary', :'out_of_office' => :'outOfOffice', :'geolocation' => :'geolocation', :'station' => :'station', :'authorization' => :'authorization', :'profile_skills' => :'profileSkills', :'date' => :'date', :'geolocation_settings' => :'geolocationSettings', :'organization' => :'organization', :'presence_definitions' => :'presenceDefinitions', :'locations' => :'locations', :'org_authorization' => :'orgAuthorization', :'favorites' => :'favorites', :'superiors' => :'superiors', :'direct_reports' => :'directReports', :'adjacents' => :'adjacents', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/purecloud/models/user_me.rb', line 177 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'chat' => :'Chat', :'department' => :'String', :'email' => :'String', :'primary_contact_info' => :'Array<Contact>', :'addresses' => :'Array<Contact>', :'state' => :'String', :'title' => :'String', :'username' => :'String', :'images' => :'Array<UserImage>', :'version' => :'Integer', :'routing_status' => :'RoutingStatus', :'presence' => :'UserPresence', :'conversation_summary' => :'UserConversationSummary', :'out_of_office' => :'OutOfOffice', :'geolocation' => :'Geolocation', :'station' => :'UserStations', :'authorization' => :'UserAuthorization', :'profile_skills' => :'Array<String>', :'date' => :'ServerDate', :'geolocation_settings' => :'GeolocationSettings', :'organization' => :'Organization', :'presence_definitions' => :'Array<OrganizationPresence>', :'locations' => :'Array<Location>', :'org_authorization' => :'Array<DomainOrganizationRole>', :'favorites' => :'Array<User>', :'superiors' => :'Array<User>', :'direct_reports' => :'Array<User>', :'adjacents' => :'Adjacents', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Check equality by comparing each attribute.
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/purecloud/models/user_me.rb', line 377 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && chat == o.chat && department == o.department && email == o.email && primary_contact_info == o.primary_contact_info && addresses == o.addresses && state == o.state && title == o.title && username == o.username && images == o.images && version == o.version && routing_status == o.routing_status && presence == o.presence && conversation_summary == o.conversation_summary && out_of_office == o.out_of_office && geolocation == o.geolocation && station == o.station && == o. && profile_skills == o.profile_skills && date == o.date && geolocation_settings == o.geolocation_settings && organization == o.organization && presence_definitions == o.presence_definitions && locations == o.locations && == o. && favorites == o.favorites && superiors == o.superiors && direct_reports == o.direct_reports && adjacents == o.adjacents && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/purecloud/models/user_me.rb', line 443 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/purecloud/models/user_me.rb', line 503 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/purecloud/models/user_me.rb', line 424 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
414 415 416 |
# File 'lib/purecloud/models/user_me.rb', line 414 def eql?(o) self == o end |
#hash ⇒ Object
Calculate hash code according to all attributes.
419 420 421 |
# File 'lib/purecloud/models/user_me.rb', line 419 def hash [id, name, chat, department, email, primary_contact_info, addresses, state, title, username, images, version, routing_status, presence, conversation_summary, out_of_office, geolocation, station, , profile_skills, date, geolocation_settings, organization, presence_definitions, locations, , favorites, superiors, direct_reports, adjacents, self_uri].hash end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
486 487 488 |
# File 'lib/purecloud/models/user_me.rb', line 486 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
491 492 493 494 495 496 497 498 499 |
# File 'lib/purecloud/models/user_me.rb', line 491 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
481 482 483 |
# File 'lib/purecloud/models/user_me.rb', line 481 def to_s to_hash.to_s end |